pitchtools.NumberedPitchObject
==============================

.. abjad-lineage:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject

.. autoclass:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__abs__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__repr__
   :noindex:
